Package 'ccmatch'

Title: R package for optimal matching of cases to controls using network flow theory.
Description: This package implements optimal matching of cases to controls at a given ratio by solving a minimum cost flow problem.
Authors: Masahiro Kanai
Maintainer: Masahiro Kanai <[email protected]>
License: GPL (>= 2)
Version: 1.0
Built: 2026-05-20 10:04:36 UTC
Source: https://github.com/mkanai/ccmatch

Help Index


Conduct optimal matching of cases to controls using network flow theory.

Description

Conduct optimal matching of cases to controls using network flow theory.

Usage

ccmatch(x.case, x.control, n = 1, display_progress = TRUE,
  method = "Euclidean", ...)

Arguments

x.case

a numeric matrix.

x.control

a numeric matrix.

n

a ratio of case:control.

display_progress

a logical indicating whether to display a progress bar.

method

a function, a registry entry, or a mnemonic string referencing the proximity measure passed to proxy::dist.

...

further arguments passed to proxy::dist.

References

http://dx.doi.org/10.2307/2290079


ccmatch

Description

R package for optimal matching of cases to controls using network flow theory.

Author(s)

Masahiro Kanai

References

http://dx.doi.org/10.2307/2290079