| Title: | R package for optimal matching of cases to controls using network flow theory. |
|---|---|
| Description: | This package implements optimal matching of cases to controls at a given ratio by solving a minimum cost flow problem. |
| Authors: | Masahiro Kanai |
| Maintainer: | Masahiro Kanai <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-20 10:04:36 UTC |
| Source: | https://github.com/mkanai/ccmatch |
Conduct optimal matching of cases to controls using network flow theory.
ccmatch(x.case, x.control, n = 1, display_progress = TRUE, method = "Euclidean", ...)ccmatch(x.case, x.control, n = 1, display_progress = TRUE, method = "Euclidean", ...)
x.case |
a numeric |
x.control |
a numeric |
n |
a ratio of case:control. |
display_progress |
a logical indicating whether to display a progress bar. |
method |
a function, a registry entry, or a mnemonic string referencing the proximity measure passed to |
... |
further arguments passed to |
http://dx.doi.org/10.2307/2290079
R package for optimal matching of cases to controls using network flow theory.
Masahiro Kanai
http://dx.doi.org/10.2307/2290079